summaryrefslogtreecommitdiff
path: root/errors.go
diff options
context:
space:
mode:
authorWolfy-J <[email protected]>2020-10-25 15:55:51 +0300
committerWolfy-J <[email protected]>2020-10-25 15:55:51 +0300
commitba5c562f9038ba434e655fb82c44597fcccaff16 (patch)
treeff112b9dcffda63bc40094a57d0df61622368445 /errors.go
parent3bdf7d02d83d1ff4726f3fbb01a45d016f39abec (diff)
- massive update in roadrunner 2.0 abstractions
Diffstat (limited to 'errors.go')
-rw-r--r--errors.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/errors.go b/errors.go
index b9746702..52356549 100644
--- a/errors.go
+++ b/errors.go
@@ -1,11 +1,11 @@
package roadrunner
// TaskError is job level error (no WorkerProcess halt), wraps at top
// of error context
-type TaskError []byte
+type JobError []byte
// Error converts error context to string
-func (te TaskError) Error() string {
+func (te JobError) Error() string {
return string(te)
}
@@ -1,11 +1,11 @@
package roadrunner
-// TaskError is job level error (no WorkerProcess halt), wraps at top
+// JobError is job level error (no WorkerProcess halt), wraps at top
// of error context